spacepy.irbempy.get_AEP8 — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.get_AEP8

`spacepy.irbempy.` `get_AEP8`(energy, loci, model='min', fluxtype='diff', particles='e')

  will return the flux from the AE8-AP8 model

  Parameters: | - energy (float) : center energy in MeV; if fluxtype=RANGE, then needs to be a list [Emin, Emax] loci (Coords) : a Coords instance with the location inside the magnetosphere optional instead of a Coords instance, one can also provide a list with [BBo, L] combination model (str) : MIN or MAX for solar cycle dependence fluxtype (str) : DIFF, RANGE, INT are possible types particles (str): e or p or electrons or protons
  Returns: | - float : flux from AE8/AP8 model

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »